package com.ynet.life.credit.business;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.log.GENELog;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.credit.dao.SequenceNoGetter;
import com.ynet.life.credit.dao.SqlExcutor;
import com.ynet.life.credit.dao.SqlQueryTester;
import com.ynet.life.credit.util.IOUtil;
import com.ynet.life.credit.util.TimeUtils;
import com.ynet.life.credit.vo.input.CreditDetailVo;
import com.ynet.life.credit.vo.output.CreditOutListVo;
import com.ynet.life.credit.vo.output.CreditOutWhenCreditVo;
import com.ynet.life.credit.vo.output.OutBaseVo;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.util.PropertiesFile;
import edu.emory.mathcs.backport.java.util.Arrays;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;
import java.util.UUID;
import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_ynet_life_credit_business.jar:com/ynet/life/credit/business/GetCreditJsonWhenCreditExcutor.class */
public class GetCreditJsonWhenCreditExcutor extends BaseApiExcutor<CreditOutWhenCreditVo> {
    public static String[] error_table = {"mList", "tList", "fList", "bList", "iList", "nList", "jList", "zList", "sList", "hList", "cList", "rList", "kList"};
    private static String CREDIT_COMPONENT = "【【征信获取征信报告接口】】";

    @Override // com.ynet.life.credit.business.BaseApiExcutor
    public String execute(Context context) throws GENEException {
        String result;
        KeyedCollection coll = context.getDataElement();
        String nowTime = TimeUtils.getNowTime("yyyyMMddhhmmss");
        List<String> sqlList = new ArrayList<>();
        Throwable th = null;
        try {
            Long timeStamp1 = TimeUtils.getNowTimeStamp();
            CreditDetailVo vo = new CreditDetailVo();
            Properties bankDBSourceProperties = PropertiesFile.getProperties("/properties/creditApiPath.properties");
            String urlApi = bankDBSourceProperties.getProperty("creditDetailUrl");
            String wsUser = bankDBSourceProperties.getProperty("wsUser");
            String productMode = bankDBSourceProperties.getProperty("productMode");
            CreditDetailVo vo2 = vo.contextToInBaseVo(coll);
            if (!StringUtils.isBlank(vo2.getFCI_CORNO())) {
                GENELog.log(CREDIT_COMPONENT, GENELog.INFO, 0, "请求参数==" + vo2.toString());
                vo2.setApiAddr(urlApi);
                vo2.setWsUser(wsUser);
                vo2.setBusiSeq(UUID.randomUUID().toString());
                if ("false".equals(productMode)) {
                    result = IOUtil.readLocalFile(bankDBSourceProperties.getProperty("jsonFilePath"));
                } else {
                    result = getReport(vo2, urlApi);
                }
                Arrays.asList(new String[]{"busiSeq", "cardType", "cardCode", "wsUser"});
                Long timeStamp2 = TimeUtils.getNowTimeStamp();
                String reqCost = String.valueOf(timeStamp2.longValue() - timeStamp1.longValue());
                new CreditOutWhenCreditVo();
                for (int i = 0; i < error_table.length; i++) {
                    result = result.replaceAll("\"" + error_table[i] + "\"", "\"" + error_table[i].toLowerCase() + "\"");
                }
                String corno = vo2.getFCI_CORNO();
                CreditOutWhenCreditVo out = (CreditOutWhenCreditVo) parseStringToObject(result, CreditOutWhenCreditVo.class);
                out.setD2_credit_code(vo2.getCreditNo());
                if ("200".equals(out.getReponseCode())) {
                    out.setD2_alldata(result);
                    CreditOutListVo listout = (CreditOutListVo) parseStringToObject(result, CreditOutListVo.class);
                    SequenceNoGetter seqGeter = new SequenceNoGetter();
                    listout.setSeq_no(seqGeter.execute("creditDetailNo"));
                    listout.setFCI_CORNO(corno);
                    StringBuilder sb = new StringBuilder("select * from ");
                    out.getClass();
                    String testsql = sb.append("credit_corinf_snap_cdt where d2_credit_code = '").append(vo2.getCreditNo()).append("'").toString();
                    String seqNo = new SqlQueryTester(testsql).isHaveData();
                    out.setD2_create_time(nowTime);
                    if (StringUtils.isBlank(seqNo)) {
                        out.setSeq_no(seqGeter.execute("creditDetailNo"));
                        out.setFCI_CORNO(corno);
                        sqlList.addAll(out.toInsertSqlString());
                    } else {
                        out.setSeq_no(seqNo);
                        out.setFCI_CORNO(corno);
                        sqlList.addAll(out.toUpdateSqlString());
                    }
                } else {
                    String language = (String) getSessionCtx(context).get("session_language");
                    th = new TranFailException(out.getReponseCode(), LifeStandard.getResouceDisplayAt(out.getReponseMsg(), language), false);
                    context.put("GENEException", th);
                }
                String respCost = String.valueOf(TimeUtils.getNowTimeStamp().longValue() - timeStamp2.longValue());
                out.setBusiSeq(vo2.getBusiSeq());
                out.setFCI_CORNO(corno);
                out.setReq_data(vo2.toString());
                out.setReq_api(vo2.getApiAddr());
                out.setReq_cost_time(reqCost);
                out.setResp_cost_time(respCost);
                out.setOper_user(vo2.getUserId());
                OutBaseVo baseVo = new OutBaseVo();
                BeanUtils.copyProperties(baseVo, out);
                sqlList.add(baseVo.toLogSqlString());
                GENELog.log(CREDIT_COMPONENT, GENELog.INFO, 0, "执行脚本==" + sqlList.toString());
                SqlExcutor sqlExcutor = new SqlExcutor();
                sqlExcutor.setBatchInsertList(sqlList);
                String dbResult = sqlExcutor.execute();
                if (StringUtils.isBlank(out.getReponseCode()) || "400".equals(out.getReponseCode())) {
                    throw th;
                }
                return dbResult;
            }
            context.put("GENEException", (Object) null);
            throw new TranFailException("400", "缺少参数", false);
        } catch (Exception e) {
            GENELog.log(GENEConstance.GENE_ACTION, GENELog.ERROR, 0, e.getMessage());
            e.printStackTrace();
            return "error:".concat(String.valueOf(e));
        }
    }
}
